import { NextResponse } from 'next/server';

export async function GET() {
    const apiKey = process.env.QWEATHER_API_KEY;
    // 使用北京坐标（示例）
    const [longitude, latitude] = [116.3974, 39.9093];
    const today = new Date();

    try {
        // 获取未来6天日出日落数据
        const datePromises = Array.from({ length: 6 }).map((_, i) => {
            const date = new Date(today);
            date.setDate(today.getDate() + i);
            return date.toISOString().split('T')[0].replace(/-/g, ''); // 格式化为yyyyMMdd
        });

        const responses = await Promise.all(
            datePromises.map(date =>
                fetch(`https://devapi.qweather.com/v7/astronomy/sun?location=${longitude},${latitude}&date=${date}&key=${apiKey}`)
            )
        );

        const sunData = await Promise.all(responses.map(res => res.json()));

        // 格式化数据
        const formattedData = sunData.map((item, index) => ({
            date: new Date(today.getTime() + index * 86400000).toISOString().split('T')[0],
            sunrise: formatSunTime(item.sunrise),
            sunset: formatSunTime(item.sunset)
        }));

        return NextResponse.json(formattedData, {
            headers: {
                'Cache-Control': 'public, s-maxage=3600',
                'CDN-Cache-Control': 'public, s-maxage=7200'
            }
        });

    } catch (error) {
        console.error('日出日落数据获取失败:', error);
        return NextResponse.json(
            { error: "日出日落数据获取失败" },
            { status: 500 }
        );
    }
}

// 时间格式化函数
function formatSunTime(isoTime: string) {
    try {
        const date = new Date(isoTime);
        return date.toLocaleTimeString('zh-CN', {
            hour: '2-digit',
            minute: '2-digit',
            hour12: false
        });
    } catch {
        return isoTime.split('T')[1]?.substring(0, 5) || '--:--';
    }
}